@@ -1,6 +1,4 @@
-from functools import wraps
-from functools import cache as optimize
-import time
+from functools import cache
 from time import perf_counter
 import sys
 
@@ -44,11 +42,8 @@ def get_time(func):
 
     return wrapper
 
+@cache
 def setup():
     sys.setrecursionlimit(1000000000)
     return "Setup Done."
 
-
-print(setup())
-print(sys.getrecursionlimit())
-
